@@ -21,7 +21,7 @@ class Request : public QDBusVirtualObject
 {
     Q_OBJECT
 public:
-    explicit Request(const QDBusObjectPath &handle, QObject *parent = nullptr, const QString &portalName = QString(), const QVariant &data = QVariant());
+    explicit Request(const QDBusObjectPath &handle, QObject *parent = nullptr);
 
     bool handleMessage(const QDBusMessage &message, const QDBusConnection &connection) override;
     QString introspect(const QString &path) const override;
@@ -44,10 +44,6 @@ public:
 
 Q_SIGNALS:
     void closeRequested();
-
-private:
-    const QVariant m_data;
-    const QString m_portalName;
 };
 
 #endif // XDG_DESKTOP_PORTAL_KDE_REQUEST_H
